@@ -1,9 +1,9 @@
 package Log::ger::Layout::Pattern;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-11'; # DATE
+our $DATE = '2020-04-19'; # DATE
 our $DIST = 'Log-ger-Layout-Pattern'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,6 +18,7 @@ our $time_now   = $time_start;
 our $time_last  = $time_start;
 
 my %per_message_data;
+my %cache;
 
 our %format_for = (
     'c' => sub { $_[1]{category} },
@@ -65,6 +66,17 @@ our %format_for = (
         join(", ", map { "$_->[3] called at $_->[1] line $_->[2]" }
                  @{ $per_message_data{callers} });
     },
+    '_{vmsize}' => sub {
+        unless ($cache{pid_stat_time} &&
+                $cache{pid_stat_time} >= $time_now-1) {
+            open my $fh, "/proc/$$/stat" or die;
+            $cache{pid_stat} = [split /\s+/, scalar(<$fh>)];
+            $cache{pid_stat_time} = $time_now;
+            close $fh;
+        }
+        sprintf("%d", $cache{pid_stat}[22]/1024);
+    },
+
     # test
     #'z' => sub { use DD; my $i = 0; while (my @c = caller($i++)) { dd \@c } },
     '%' => sub { '%' },
@@ -74,6 +86,7 @@ sub meta { +{
     v => 2,
 } }
 
+my $re = qr/%(_\{\w+\}|[A-Za-z%])/;
 sub _layout {
     my $format = shift;
     my $packages_to_ignore = shift;
@@ -83,7 +96,7 @@ sub _layout {
     %per_message_data = ();
 
     my %mentioned_formats;
-    while ($format =~ m/%(.)/g) {
+    while ($format =~ m/$re/g) {
         if (exists $format_for{$1}) {
             $mentioned_formats{$1} = 1;
         } else {
@@ -110,7 +123,7 @@ sub _layout {
             [Devel::Caller::Util::callers(0, 0, $packages_to_ignore, $subroutines_to_ignore)];
     }
 
-    $format =~ s#%(.)#$format_for{$1}->(@_)#eg;
+    $format =~ s#$re#$format_for{$1}->(@_)#eg;
     $format;
 }
 
@@ -153,7 +166,7 @@ Log::ger::Layout::Pattern - Pattern layout
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -185,6 +198,9 @@ Known placeholder in format string:
  %T A stack trace of functions called
  %% A literal percent (%) sign
 
+ %_{vmsize}  Process virtual memory size, in KB.
+    Currently works on Linux only. Value is cached for 1 second.
+
 =for Pod::Coverage ^(.+)$
 
 =head1 CONFIGURATION
@@ -205,7 +221,7 @@ this to L<Devel::Caller::Util>'s C<caller()> or C<callers()>.
 
 L<Log::ger::Layout::Pattern::Multiline>
 
-Modelled after L<Log::Log4perl::Layout::Pattern> but note that full
+Modelled after L<Log::Log4perl::Layout::PatternLayout> but note that full
 compatibility or feature parity is not a goal. See also L<Log::Log4perl::Tiny>.
 
 L<Log::ger>
